

from setuptools import setup, find_packages

setup(
    name='llm_monitor',
    version='0.0.0',
    packages=find_packages(),
    description='https://pypi.org/project/llm-monitor/',
    author='Franz',
    author_email='franz@rungalileo.io',
    url='https://pypi.org/project/llm-monitor/',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
